let baseWebpackConfig = require('./shared/baseWebpackConfig');
let jarbConfig = require('../../scripts/util/config');
let fileName = '[name].js';
let CaseSensitivePathsPlugin = require('case-sensitive-paths-webpack-plugin');
let MiniCssExtractPlugin = require('mini-css-extract-plugin');
let path = require('path');
let webpack = require('webpack');
let {rules} = require('./shared/rules');
const UglifyJsPlugin = require('uglifyjs-webpack-plugin');
let BundleAnalyzerPlugin = require('webpack-bundle-analyzer').BundleAnalyzerPlugin;

let entryFiles = {
  index: `${process.cwd()}/src/index`
};

let webpackConfiguration = Object.assign({}, baseWebpackConfig, {
  mode: 'production',
  entry: entryFiles,
  cache: false,
  output: {
    path: `${process.cwd()}/dist`,
    filename: fileName,
    publicPath: jarbConfig.assetsPath,
    libraryTarget: 'umd',
    sourceMapFilename: '[file].map'
  },
  plugins: [
    new CaseSensitivePathsPlugin(),
    new webpack.optimize.AggressiveMergingPlugin(),
    new MiniCssExtractPlugin({
      // Options similar to the same options in webpackOptions.output
      // both options are optional
      filename: 'bundle.css',
      chunkFilename: '[id].css'
    }),
    new webpack.DefinePlugin({
      'process.env': jarbConfig.envVariables
    })
  ],
  module: {
    rules: [...rules]
  },
  optimization: {
    minimizer :[]
  },
  performance: {
    hints: process.env.NODE_ENV === 'production' ? 'warning' : false
  }
});



if (jarbConfig.analyzeBundle) {
  webpackConfiguration.plugins.push(new BundleAnalyzerPlugin({
    analyzerMode: 'static',
    reportFilename: 'report.html'
  }));
}

if (jarbConfig.minified) {
  webpackConfiguration.optimization.minimizer.push(
    new UglifyJsPlugin({
      sourceMap: true,
      cache: true
    })
  );
}

module.exports = webpackConfiguration;